@@ -12,6 +12,7 @@ use DateTime;
 use DateTime::Format::Strptime;
 use Digest::MD5 qw(md5_hex);
 use Encode      qw(decode encode);
+use IO::Socket::SSL;
 use JSON;
 use LWP::UserAgent;
 use Travel::Status::DE::HAFAS::Journey;
@@ -22,7 +23,7 @@ use Travel::Status::DE::HAFAS::Product;
 use Travel::Status::DE::HAFAS::Services;
 use Travel::Status::DE::HAFAS::StopFinder;
 
-our $VERSION = '6.18';
+our $VERSION = '6.19';
 
 # {{{ Endpoint Definition
 
@@ -52,6 +53,11 @@ sub new {
 				$lwp_options{proxy} = [ [ 'http', 'https' ] => $proxy ];
 			}
 		}
+		if ( $service and not $hafas_instance->{$service}{tls_verify} ) {
+			$lwp_options{ssl_opts}{SSL_verify_mode}
+			  = IO::Socket::SSL::SSL_VERIFY_NONE;
+			$lwp_options{ssl_opts}{verify_hostname} = 0;
+		}
 		$ua = LWP::UserAgent->new(%lwp_options);
 		$ua->env_proxy;
 	}
@@ -904,7 +910,7 @@ monitors
 
 =head1 VERSION
 
-version 6.18
+version 6.19
 
 =head1 DESCRIPTION
 
